/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "materialShader.h"


MaterialShader::MaterialShader(int nbLightsDir, int nbLightsSpot, int nbLightsPoint,
							   int nbColorMaps, int nbNormalMaps, int nbGlossMaps, int nbEmiMaps):
	Shader(), mNbLightsDir(nbLightsDir), mNbLightsSpot(nbLightsSpot), mNbLightsPoint(nbLightsPoint),
	mNbColorMaps(nbColorMaps), mNbNormalMaps(nbNormalMaps), mNbGlossMaps(nbGlossMaps), mNbEmiMaps(nbEmiMaps) {
			
}



void MaterialShader::setLocations() {
	locationTangent = glGetAttribLocation(id, "tangent");

	
	if(mNbColorMaps) {
		locationColorMap = glGetUniformLocation(id, "colorMap");
		//glUniform1i(locationNbColorMaps, mNbColorMaps);	
	}	
	
	if(mNbNormalMaps) {
		locationNormalMap = glGetUniformLocation(id, "normalMap");
		//glUniform1i(locationNbNormalMaps, mNbNormalMaps);		
	}	
	
	if(mNbGlossMaps) {
		locationGlossMap = glGetUniformLocation(id, "glossMap");	
		//glUniform1i(locationNbGlossMaps, mNbGlossMaps);		
	}	
	
	if(mNbEmiMaps) {
		locationEmiMap = glGetUniformLocation(id, "emiMap");	
		//glUniform1i(locationNbEmiMaps, mNbEmiMaps);	
	}
		
	locationSkyColor = glGetUniformLocation(id, "skyColor");	
	locationGroundColor = glGetUniformLocation(id, "groundColor");	
	
	locationHemiAxis = glGetUniformLocation(id, "hemiAxis");
}



int MaterialShader::getLocationTangent() {
	return locationTangent;
}


/*	Color maps	*/
int MaterialShader::getNbColorMaps() {
	return mNbColorMaps;
}

int MaterialShader::getLocationNbColorMaps() {
	return locationNbColorMaps;	
}

void MaterialShader::setIdColorMap(int id) {
	glUniform1i	(locationColorMap, id);	
}

int MaterialShader::getLocationColorMap() {
	return locationColorMap;
}

/* Normal maps	*/
int MaterialShader::getNbNormalMaps() {
	return mNbNormalMaps;
}

int MaterialShader::getLocationNbNormalMaps() {
	return locationNbNormalMaps;
}

void MaterialShader::setIdNormalMap(int id) {
	glUniform1i	(locationNormalMap, id);	
}

int MaterialShader::getLocationNormalMap() {
	return locationNormalMap;
}


/*	Gloss maps	*/	
int MaterialShader::getNbGlossMaps() {
	return mNbGlossMaps;
}

int MaterialShader::getLocationNbGlossMaps() {
	return locationNbGlossMaps;
}

void MaterialShader::setIdGlossMap(int id) {
	glUniform1i	(locationGlossMap, id);	
}

int MaterialShader::getLocationGlossMap() {
	return locationGlossMap;
}


/*	Emission maps	*/
int MaterialShader::getNbEmiMaps() {
	return mNbEmiMaps;
}

int MaterialShader::getLocationNbEmiMaps() {
	return locationNbEmiMaps;
}

void MaterialShader::setIdEmiMap(int id) {
	glUniform1i	(locationEmiMap, id);	
}

int MaterialShader::getLocationEmiMap() {
	return locationEmiMap;
}



void MaterialShader::setNumMaps(int color, int normal, int gloss, int emi) {
	if(color >= 0) {
		glUniform1i	(locationColorMap, color);	
	}
	if(normal >=0) {
		glUniform1i	(locationNormalMap, normal);	
	}
	if(gloss >=0) {
		glUniform1i	(locationGlossMap, gloss);	
	}
	if(emi >=0) {
		glUniform1i	(locationEmiMap, emi);	
	}
}


void MaterialShader::setAmbientColors(Color groundColor, Color skyColor, Vector3 hemiAxis) {
	glUniform3f(locationGroundColor, groundColor.r, groundColor.g, groundColor.b);	
	glUniform3f(locationSkyColor, skyColor.r, skyColor.g, skyColor.b);
	glUniform3fv(locationHemiAxis, 1, hemiAxis);
}	














